@@ -1,14 +1,15 @@
-import json, re, requests, private_data, pickle, tempfile, os
-from os import path
-from datetime import datetime
+import json, re, requests, pickle
+from os import path, environ, remove
+from datetime import datetime, timedelta
 from dateutil import parser, tz
 from lxml import html
+from tempfile import gettempdir
 
 # Global value modified by login_to_dk()
 login_valid = False
-stored_cookies = tempfile.gettempdir() + '/stored_cookies'
+stored_cookies = gettempdir() + '/stored_cookies'
 
-def login_to_dk(session, cookies_file=stored_cookies, login_data=private_data.creds, strict=False):
+def login_to_dk(session, cookies_file=stored_cookies, strict=False):
     # The following lines read a global variable to reduce the time it takes to process this function
     # Without this check, calling this function would always verify cookies each time it is called
     # This function will run at least once, but can be presumed True afterwards
@@ -16,6 +17,19 @@ def login_to_dk(session, cookies_file=stored_cookies, login_data=private_data.cr
     global login_valid
     if login_valid and not strict:
         return True
+
+    # Read values from environment
+    dk_user = environ['DKUSER']
+    dk_pass = environ['DKPASS']
+
+    # Use a method to create and return the string
+    def create_login_string(dk_user, dk_pass):
+        login_dict = {'login': dk_user, 'password': dk_pass, 'host':'api.draftkings.com', 'challengeResponse':{'solution': '', 'type': 'Recaptcha'}}
+        login_json = json.dumps(login_dict)
+        return login_json.replace(' ', '')
+
+    login_data = create_login_string(dk_user, dk_pass)
+
     # Session used to check cookies before they are passed to 'session' object
     temp_session = requests.session()
     
@@ -42,7 +56,7 @@ def login_to_dk(session, cookies_file=stored_cookies, login_data=private_data.cr
         except:
             # There is a problem with the data in the provided cookies_file
             # Remove cookies_file and run this function again to reach the following else statement
-            os.remove(cookies_file)
+            remove(cookies_file)
             return login_to_dk(session)
     else:
         # Get new cookies to be stored in cookies_file
@@ -55,7 +69,7 @@ def login_to_dk(session, cookies_file=stored_cookies, login_data=private_data.cr
             return True
         # If login and GET fail, then output the status code, headers and text of the login attempt
         else:
-            print(f"Failed login attempt, status code: {login_attempt.status_code}.\nHeaders:\n{login_attempt.headers}\nText:{login_attempt.text}")
+            print(f"Failed login attempt, status code: {login_attempt.status_code}.\nHeaders:\n{login_attempt.headers}\nText:{login_attempt.text}\nCredentials:{login_data}")
             login_valid = False
             return False  
 
@@ -69,7 +83,7 @@ def store_cookies(session, cookies_file=stored_cookies):
         with open(cookies_file, 'wb') as f:
             pickle.dump(session.cookies, f)
 
-def get_all_players(session, week, year=2020):
+def get_all_players(session, week, year):
     # Function to obtain JSON (as a dictionary) of all player stats including fantasy points and salary
     # Header used in POST request
     weekly_headers = {
@@ -165,11 +179,9 @@ def get_all_drafted(session, contest_id):
                 all_players.append(player)
     return all_players
 
-def set_winning_value(rank, values=None):
-    if not values:
-        values = private_data.values
-    if values.get(rank):
-        return values.get(rank)
+def set_winning_value(rank, winning_values):
+    if winning_values.get(rank):
+        return winning_values.get(rank)
     else:
         return 0
 
@@ -257,7 +269,14 @@ def get_draft_dodger(all_players, all_drafted):
 
     return draft_dodger
 
-def generate_results(session, contest_id, week, year=2020):
+def generate_results(session, contest_id, week=None, year=None, winning_values=None):
+    if week is None or year is None:
+        contest_date = get_date(session, contest_id)
+        if week is None:
+            week = contest_date['week']
+        if year is None:
+            year = contest_date['year']
+
     # Returns a dict including the week and list of members with their rank and fantasyPoints
     # Start with an empty list
     members_filtered = []
@@ -269,7 +288,7 @@ def generate_results(session, contest_id, week, year=2020):
             "userName": member['userName'],
             "rank": member['rank'],
             "fantasyPoints": member['fantasyPoints'],
-            "winningValue": set_winning_value(member['rank'])
+            "winningValue": set_winning_value(member['rank'], winning_values)
         }
         members_filtered.append(member_weekly)
     
@@ -301,7 +320,13 @@ def generate_results(session, contest_id, week, year=2020):
     }
     return members_dict
 
-def add_weekly_json(json_file, session, contest_id, week, year=2020):
+def add_weekly_json(json_file, session, contest_id, week=None, year=None):
+    if week is None or year is None:
+        contest_date = get_date(session, contest_id)
+        if week is None:
+            week = contest_date['week']
+        if year is None:
+            year = contest_date['year']
     # If the json_file does not exist or contains invalid data, start wih an empty list
     try:
         with open(json_file) as f:
@@ -361,19 +386,35 @@ def get_contest_start(contest_details):
     return contest_start
 
 def get_submitted_list(session, contest_id):
-    
+    # The URL of the page containing contest data before contest is live
     url = f"https://www.draftkings.com/contest/detailspop?contestId={contest_id}"
 
+    # Verify login
     if login_to_dk(session):
         get_submitted = session.get(url)
+        # If page is loaded successfully, get the list of users from entrants-table
         if get_submitted.status_code == requests.codes.ok:
             tree = html.fromstring(get_submitted.content)
             entrants = tree.xpath('//*[@id="entrants-table"]/tbody/tr[*]/td[*]/span/text()')
             return entrants
 
-def get_not_submitted_list(session, contest_id, all_members=None):
-    if not all_members:
-        all_members = set(private_data.all_members)
+def get_not_submitted_list(session, contest_id, all_members):
+    # Provide all_members as a set
     submitted = set(get_submitted_list(session, contest_id))
     not_submitted = all_members - submitted
-    return not_submitted
+    return list(not_submitted)
+
+def get_date(session, contest_id, week1='Sep 10, 2020 20:20:00'):
+    contest_details = get_contest_details(session, contest_id)
+
+    contest_start_string = get_contest_start(contest_details)
+    week1_date = datetime.strptime(week1, '%b %d, %Y %H:%M:%S')
+    contest_start = datetime.strptime(contest_start_string, '%b %d, %Y %H:%M:%S')
+    
+    week_num = (contest_start - week1_date).days / 7
+
+    week_dict = dict()
+    week_dict['week'] = int(week_num + 1)
+    week_dict['year'] = contest_start.year
+
+    return week_dict
\ No newline at end of file
